@@ -4,22 +4,12 @@ from fastgenerateapi.settings.all_settings import settings
 class WsRouter:
 
     def __init__(self, router_class, path, func_name):
-        router_args = router_class.router_args.get(func_name, {}) if router_class.router_args else {}
-        if router_args and isinstance(router_args, list):
-            router_args = {"dependencies": router_args}
-
-        self.dependencies = router_args.get("dependencies") if router_args and router_args.get("dependencies") else []
+        self.dependencies = []
         self.path = path
         self.func_name = func_name
 
-        name = None
-        if router_args and router_args.get("name"):
-            name = router_args.get("name")
-        if name is None:
-            doc = getattr(router_class, func_name).__doc__
-            if doc:
-                name = doc.strip().split("\n")[0]
-        self.name = name or None
+        doc = getattr(router_class, func_name).__doc__
+        self.name = doc.strip().split("\n")[0] if doc else None
 
 
 class WsController:
