@@ -5,6 +5,7 @@ from pydantic.fields import FieldInfo
 
 from fastgenerateapi.pydantic_utils.base_model import model_config
 from fastgenerateapi.pydantic_utils.base_model import ModelConfig
+from fastgenerateapi.schemas_factory.common_function import get_validate_dict
 from fastgenerateapi.settings.all_settings import settings
 
 from pydantic import BaseModel, create_model
@@ -26,7 +27,12 @@ def tree_params_deps():
         )
     }
 
-    filter_tree_params_model: Type[BaseModel] = create_model("TreeFilterParams", __config__=model_config, **model_fields)
+    filter_tree_params_model: Type[BaseModel] = create_model(
+        "TreeFilterParams",
+        **model_fields,
+        __config__=model_config,
+        __validators__=get_validate_dict(),
+    )
 
     def filter_query(filter_params: filter_tree_params_model = Depends(filter_tree_params_model)) -> Optional[str]:
         """
