@@ -6,6 +6,7 @@ import fastapi
 from fastapi import params
 from fastapi.dependencies.models import Dependant
 from fastapi.dependencies.utils import get_sub_dependant
+from pydantic.alias_generators import to_snake, to_camel
 
 
 def get_param_sub_dependant(
@@ -25,10 +26,16 @@ def get_param_sub_dependant(
     )
     for query_param in dependant.query_params:
         query_param_field = depends.dependency.model_fields.get(query_param.name)
+        if not query_param_field:
+            snake_name = to_snake(query_param.name)
+            if query_param.name != snake_name:
+                query_param_field = depends.dependency.model_fields.get(snake_name)
+        if not query_param_field:
+            camel_name = to_camel(query_param.name)
+            if query_param.name != camel_name:
+                query_param_field = depends.dependency.model_fields.get(camel_name)
         if query_param_field:
             query_param.field_info.description = query_param_field.description or query_param_field.title or ""
-        else:
-            query_param.field_info.description = query_param_field.description or query_param_field.title or ""
     return dependant
 
 
