@@ -27,8 +27,8 @@ class SoftDeleteField(BigIntField):
 
     def __init__(self, **kwargs: Any) -> None:
         kwargs.setdefault("index", True)
-        kwargs.setdefault("null", True)
-        kwargs.setdefault("default", None)
+        kwargs.setdefault("null", False)
+        kwargs.setdefault("default", 0)
         kwargs.setdefault("description", "软删除")
         super().__init__(**kwargs)
 
