@@ -1,4 +1,4 @@
-from typing import Type, Union
+from typing import Type, Union, Optional
 
 from fastapi import Query
 from pydantic import BaseModel, create_model
@@ -9,6 +9,8 @@ from fastgenerateapi.api_view.mixin.dbmodel_mixin import DBModelMixin
 from fastgenerateapi.controller.filter_controller import BaseFilter
 from tortoise import Model
 
+from fastgenerateapi.schemas_factory.common_function import get_validate_dict
+
 
 def filter_schema_factory(model_class: Type[Model], fields: list[str, tuple[str, Type], BaseFilter] = None):
     """
@@ -24,7 +26,7 @@ def filter_schema_factory(model_class: Type[Model], fields: list[str, tuple[str,
         description = DBModelMixin.get_field_description(model_class, field_info.model_field)
         model_fields.update({
             f: (
-                Union[t, str],
+                Optional[t],
                 FieldInfo(
                     title=f"{description}",
                     default=Query("", description=description),
@@ -32,7 +34,12 @@ def filter_schema_factory(model_class: Type[Model], fields: list[str, tuple[str,
                 ))
         })
 
-    filter_params_model: Type[BaseModel] = create_model("CommonFilterParams", **model_fields, __config__=model_config)
+    filter_params_model: Type[BaseModel] = create_model(
+        model_class.__name__+"CommonFilterParams",
+        **model_fields,
+        __config__=model_config,
+        __validators__=get_validate_dict(),
+    )
 
     return filter_params_model
 
