@@ -1,10 +1,10 @@
 from typing import Optional
 
 from pydantic import Field
-from pydantic_settings import BaseSettings
+from pydantic_settings import BaseSettings, SettingsConfigDict
 
 
-class FileServerSettings(BaseSettings):
+class FileSettings(BaseSettings):
     """
     文件配置
     """
@@ -12,11 +12,17 @@ class FileServerSettings(BaseSettings):
     FILE_URL: Optional[str] = Field(default='/static/', description="文件路径前缀", title="file url prefix")
     FILE_ROOT: Optional[str] = Field(default='static', description="文件储存路径", title="file storage path")
 
-    class Config:
-        env_prefix = 'FileServer_'
-        env_file = "./.env"
-        case_sensitive = True
-        extra = 'allow'
+    model_config = SettingsConfigDict(
+        env_file=".env",
+        case_sensitive=True,
+        extra='ignore'
+    )
+
+    # class Config:
+    #     env_prefix = 'FILESERVER_'
+    #     env_file = "./.env"
+    #     case_sensitive = True
+    #     extra = 'allow'
 
 
 
