@@ -1,7 +1,7 @@
 from typing import Optional
 
 from pydantic import Field
-from pydantic_settings import BaseSettings
+from pydantic_settings import BaseSettings, SettingsConfigDict
 
 
 class JWTSettings(BaseSettings):
@@ -13,11 +13,18 @@ class JWTSettings(BaseSettings):
     ACCESS_TOKEN_EXPIRE_MINUTES: Optional[int] = Field(default=30, description="过期时间 (分钟)", title="JWT Access Token")
     REFRESH_TOKEN_EXPIRE_MINUTES: Optional[int] = Field(default=60, description="过期时间（分钟）", title="JWT Refresh Token")
 
-    class Config:
-        env_prefix = 'JWT_'
-        env_file = "./.env"
-        case_sensitive = True
-        extra = 'allow'
+    model_config = SettingsConfigDict(
+        env_prefix="JWT_",
+        env_file=".env",
+        case_sensitive=True,
+        extra='ignore'
+    )
+
+    # class Config:
+    #     env_prefix = 'JWT_'
+    #     env_file = "./.env"
+    #     case_sensitive = True
+    #     extra = 'allow'
 
 
 
