@@ -1,7 +1,7 @@
 from typing import Optional
 
 from pydantic import Field
-from pydantic_settings import BaseSettings
+from pydantic_settings import BaseSettings, SettingsConfigDict
 
 
 class SmsSettings(BaseSettings):
@@ -15,11 +15,18 @@ class SmsSettings(BaseSettings):
     CHECK_CODE_RESEND_TIME: Optional[int] = Field(default=1, description="验证码重新发送时间", title="check code resend time (minute)")
     DEFAULT_CODE: Optional[int] = Field(default="654123", description="默认验证码", title="sms default code")
 
-    class Config:
-        env_prefix = 'Sms_'
-        env_file = "./.env"
-        case_sensitive = True
-        extra = 'allow'
+    model_config = SettingsConfigDict(
+        env_prefix="SMS_",
+        env_file=".env",
+        case_sensitive=True,
+        extra='ignore'
+    )
+
+    # class Config:
+    #     env_prefix = 'SMS_'
+    #     env_file = "./.env"
+    #     case_sensitive = True
+    #     extra = 'allow'
 
 
 
