@@ -22,9 +22,15 @@ class SystemSettings(BaseSettings):
     DATACENTER_ID: Optional[int] = Field(default='1', description="机器ID")
 
     class Config:
-        env_prefix = ''
+        env_prefix = 'SYSTEM_'
         env_file = "./.env"
         case_sensitive = True
-        extra = 'allow'
+        extra = 'ignore'
+
+    # class Config:
+    #     env_prefix = 'SYSTEM_'
+    #     env_file = "./.env"
+    #     case_sensitive = True
+    #     extra = 'allow'
 
 
